==> pf4-component-mapper-3.18.0.tgz: package/esm/dual-list-sort-button/dual-list-sort-button.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["position"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import { Button } from "@patternfly/react-core/dist/esm/components/Button/Button.js";
import { ButtonVariant } from "@patternfly/react-core/dist/esm/components/Button/Button.js";
import PficonSortCommonAscIcon from "@patternfly/react-icons/dist/esm/icons/pficon-sort-common-asc-icon";
import PficonSortCommonDescIcon from "@patternfly/react-icons/dist/esm/icons/pficon-sort-common-desc-icon";
import DualListContext from '../dual-list-context';

var DualListSortButton = function DualListSortButton(_ref) {
  var position = _ref.position,
      rest = _objectWithoutProperties(_ref, _excluded);

  var _useContext = useContext(DualListContext),
      sortConfig = _useContext.sortConfig,
      setSortConfig = _useContext.setSortConfig;

  return /*#__PURE__*/React.createElement(Button, _extends({
    variant: ButtonVariant.plain,
    onClick: sortConfig[position] === 'asc' ? function () {
      return setSortConfig(_objectSpread(_objectSpread({}, sortConfig), {}, _defineProperty({}, position, 'desc')));
    } : function () {
      return setSortConfig(_objectSpread(_objectSpread({}, sortConfig), {}, _defineProperty({}, position, 'asc')));
    },
    "aria-label": "Sort"
  }, rest), sortConfig[position] === 'asc' ? /*#__PURE__*/React.createElement(PficonSortCommonAscIcon, null) : /*#__PURE__*/React.createElement(PficonSortCommonDescIcon, null));
};

DualListSortButton.propTypes = {
  position: PropTypes.oneOf(['left', 'right'])
};
export default DualListSortButton;

==> pf4-component-mapper-3.23.0.tgz: package/esm/dual-list-sort-button/dual-list-sort-button.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["position"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import { Button } from "@patternfly/react-core/dist/dynamic/components/Button";
import { ButtonVariant } from "@patternfly/react-core/dist/dynamic/components/Button";
import PficonSortCommonAscIcon from "@patternfly/react-icons/dist/dynamic/icons/pficon-sort-common-asc-icon";
import PficonSortCommonDescIcon from "@patternfly/react-icons/dist/dynamic/icons/pficon-sort-common-desc-icon";
import DualListContext from '../dual-list-context';

var DualListSortButton = function DualListSortButton(_ref) {
  var position = _ref.position,
      rest = _objectWithoutProperties(_ref, _excluded);

  var _useContext = useContext(DualListContext),
      sortConfig = _useContext.sortConfig,
      setSortConfig = _useContext.setSortConfig;

  return /*#__PURE__*/React.createElement(Button, _extends({
    variant: ButtonVariant.plain,
    onClick: sortConfig[position] === 'asc' ? function () {
      return setSortConfig(_objectSpread(_objectSpread({}, sortConfig), {}, _defineProperty({}, position, 'desc')));
    } : function () {
      return setSortConfig(_objectSpread(_objectSpread({}, sortConfig), {}, _defineProperty({}, position, 'asc')));
    },
    "aria-label": "Sort"
  }, rest), sortConfig[position] === 'asc' ? /*#__PURE__*/React.createElement(PficonSortCommonAscIcon, null) : /*#__PURE__*/React.createElement(PficonSortCommonDescIcon, null));
};

DualListSortButton.propTypes = {
  position: PropTypes.oneOf(['left', 'right'])
};
export default DualListSortButton;
